"""export or import navigation.

Usage:
  export_import_nav.py
  export_import_nav.py gui [--smoothing=K] [--plot=boolean]
  export_import_nav.py batch FOLDER [--smoothing=K] [--plot=boolean]
  export_import_nav.py cli CMP_FILE RAB_FILE [--smoothing=K] [--plot=boolean]
  export_import_nav.py (-h | --help)

Arguments:
  gui       use the gui for single file pairs
  batch     specify the folder containing file pairs and run in batch mode
  FOLDER    specify the folder path
  cli       manually specify a cmp and then a rab file; just use command line
  SGY_FILE  full path to a segy file
  SCV_FILE  full path to a csv file

Options:
  -h --help       Show this screen.
  --batch=boolean   Use batch mode and work on whole directories [default: False]
  --export=boolean  Export navigation(False = import)  [default: True]
  --csvfile         Full path to a csv file [default: 'Use segy name']
  --version       Show version.

"""

__author__ = 'Angus Jack 24-Apr-2019'
__version__ = '0.2.3'

import pandas as pd
import segyio
from gooey import Gooey
from gooey import GooeyParser
from docopt import docopt

@Gooey(
    program_name='Navigation export/import',
    advanced=True,
    navinavigation='TABBED',
    return_to_config=False,
    show_success_modal=False,
    disable_progress_bar_animation=True
)
def do_gui():
    # global do_export, sgyfile, csvfile
    desc = "Script to either export or import sgy navigation data"
    file_help_msg = "Name of the file you want to process"
    gui_parser = GooeyParser(description=desc)
    gooey_options = {'show_border': True, 'columns': 1}
    a_group = gui_parser.add_argument_group('File pairs sgy and csv',
                                            '',
                                            gooey_options=gooey_options)
    a_group.add_argument('up_down',
                         metavar='Do you want to export or import the navigation bytes? ',
                         choices=['Export nav', 'Import nav'], default='Export nav')
    a_group.add_argument('sgy_file', help=file_help_msg, action='store', widget='FileChooser')
    a_group.add_argument('csv_file', help=file_help_msg, default='Use sgy filename', widget='FileChooser')

    args = gui_parser.parse_args()
    if 'Export nav' in args.up_down:
        do_export = True
        print('Exporting navigation')
    else:
        do_export = False
        print('Importing navigation')

    sgyfile = args.sgy_file
    csvfile = args.csv_file
    return do_export, sgyfile, csvfile


def export_nav(segyfile, csvfile):
    with segyio.open(segyfile, 'r', strict=False) as a_file:
        sou_x = a_file.attributes(segyio.TraceField.CDP_X)[:]
        sou_y = a_file.attributes(segyio.TraceField.CDP_Y)[:]

    dfx = pd.DataFrame(sou_x / 100)
    dfy = pd.DataFrame(sou_y / 100)

    dfx_y = pd.concat([dfx, dfy], axis=1)
    dfx_y.columns = ['x', 'y']

    dfx_y.to_csv(csvfile, index_label='Index', columns=['x', 'y'])


def import_nav(segyfile, csvfile):
    df = pd.read_csv(csvfile)
    # print(df)
    dfx = df['x'] * 100
    dfy = df['y'] * 100

    dfx = dfx.astype(int)
    dfy = dfy.astype(int)

    # print(dfx)
    # print(dfy)

    x_list = dfx.values.tolist()
    y_list = dfy.values.tolist()
    # x_list = dfx_y['x'].values.tolist()
    # y_list = dfx_y['y'].values.tolist()

    with segyio.open(segyfile, 'r+', strict=False) as a_file:
        for i in range(0, len(y_list)):
            for j in a_file.header[i:i + 1]:
                j[73] = x_list[i]
                j[77] = y_list[i]
                j[181] = x_list[i]
                j[185] = y_list[i]


if __name__ == '__main__':
    # do__export = False
    # sgy_file = '2D_4-37_A_brutestack_new_nav.sgy'
    # csv_file = '2D_4-37_A_brutestack.sgy_smoothed_a.csv'
    do__export, sgy_file, csv_file = do_gui()
    print(sgy_file)
    if csv_file == 'Use sgy filename':
        csv_file = sgy_file + '.csv'
    print(csv_file)
    if do__export:
        export_nav(sgy_file, csv_file)
    if not do__export:
        import_nav(sgy_file, csv_file)

    print('Reached end of main.\n')
